@@ -8,7 +8,7 @@ use Carp qw( croak );
 use Time::Local qw( timelocal );
 
 # ABSTRACT: parse directory listing using ftpparse from ftpcopy
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub parse_dir ($;$$$)
@@ -125,8 +125,8 @@ sub AUTOLOAD
   my $name;
   our $AUTOLOAD;
   ($name = $AUTOLOAD) =~ s/.*:://;
-  croak "$AUTOLOAD not defined" if $name eq 'constant';
-  my $val = constant($name);
+  croak "$AUTOLOAD not defined" if $name eq '_constant';
+  my $val = _constant($name);
   croak "$AUTOLOAD not defined" if $val == -1;
   do {
     no strict 'refs';
@@ -148,13 +148,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::Listing::Ftpcopy - parse directory listing using ftpparse from ftpcopy
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
